Control: retitle -1 Clean LyX install fails to configure correctly
Control: reassign -1 lyx
Control: tag -1 patch
Control: affects -1 sdcc

Confirmed that this is a LyX issue. A fresh install of LyX results in
the same /usr/share/lyx/configure.py failure, and removing ~/.lyx/ on an
existing install reproduces the issue. It does not occur when ~/.lyx/ is
already setup. Problem is related to the move to Python 3 and
comparisons of bytes and strings.

Following patch fixes things for me:

-----
--- configure.py.old    2018-10-05 10:45:21.568724157 +0100
+++ configure.py        2018-10-05 10:40:04.494039200 +0100
@@ -1312,8 +1312,8 @@
                 prereq_latex = b','.join(prereq_list)
             prereq_docbook = {'true':b'', 'false':b'docbook'}[bool_docbook]
             prereq = {b'LaTeX':prereq_latex, 
b'DocBook':prereq_docbook}[classtype]
-            classdeclaration = (b'"%s" "%s" "%s" "%s" "%s"'
-                               % (classname, opt, desc, avai, prereq))
+            classdeclaration = ('"%s" "%s" "%s" "%s" "%s"'
+                               % (classname, opt, desc, avai, prereq)).encode()
             if categorydeclaration != b'""':
                 return classdeclaration + b" " + categorydeclaration
         if qres != None:
@@ -1367,7 +1367,7 @@
                 foundClasses.append(cleanclass)
                 retval = processLayoutFile(file, bool_docbook)
                 if retval != b"":
-                    tx.write(retval + os.linesep)
+                    tx.write(retval + os.linesep.encode())
         tx.close()
         logger.info('\tdone')
     if not os.path.isfile('packages.lst') or not check_config:
-----

J.

-- 
/-\                             |   Trust me, you wouldn't like us
|@/  Debian GNU/Linux Developer |          when we're angry.
\-                              |

Reply via email to